searchData={"items":[{"type":"module","title":"Adbc","doc":"Bindings for Arrow Database Connectivity (ADBC).\n\nAdbc provides a standard database interface using the\nApache Arrow format.","ref":"Adbc.html"},{"type":"module","title":"Installation - Adbc","doc":"First, add `:adbc` as a dependency in your `mix.exs`:\n\n    {:adbc, \"~> 0.1\"}\n\nNow, in your config/config.exs, configure the drivers you\nare going to use:\n\n    config :adbc, :drivers, [:sqlite]\n\nIf you are using a notebook or scripting, you can also use\n`Adbc.download_driver!/1` to dynamically download one.\n\nThen start the database and the relevant connection processes\nin your supervision tree:\n\n    children = [\n      {Adbc.Database,\n       driver: :sqlite,\n       process_options: [name: MyApp.DB]},\n      {Adbc.Connection,\n       database: MyApp.DB,\n       process_options: [name: MyApp.Conn]}\n    ]\n\n    Supervisor.start_link(children, strategy: :one_for_one)\n\nIn a notebook, the above would look like this:\n\n    db = Kino.start_child!({Adbc.Database, driver: :sqlite})\n    conn = Kino.start_child!({Adbc.Connection, database: db})\n\nAnd now you can make queries with:\n\n    # For named connections\n    {:ok, _} = Adbc.Connection.query(MyApp.Conn, \"SELECT 123\")\n\n    # When using the conn PID directly\n    {:ok, _} = Adbc.Connection.query(conn, \"SELECT 123\")","ref":"Adbc.html#module-installation"},{"type":"module","title":"Supported drivers - Adbc","doc":"Below we list all drivers supported out of the box. You may also\ngive the full path to a driver in the `:driver` option to load other\nexisting drivers.","ref":"Adbc.html#module-supported-drivers"},{"type":"module","title":"DuckDB - Adbc","doc":"The DuckDB driver provides access to in-memory DuckDB databases.\n\n#### Examples\n\n    {Adbc.Database, driver: :duckdb}","ref":"Adbc.html#module-duckdb"},{"type":"module","title":"PostgreSQL - Adbc","doc":"The PostgreSQL driver provides access to any database that supports\nthe PostgreSQL wire format. It is implemented as a wrapper around\n`libpq`.\n\n#### Examples\n\n    {Adbc.Database, driver: :postgresql, uri: \"postgresql://postgres@localhost\"}\n\nYou must pass the `:uri` option using Postgres'\n[connection URI](https://www.postgresql.org/docs/current/libpq-connect.html#LIBPQ-CONNSTRING):","ref":"Adbc.html#module-postgresql"},{"type":"module","title":"Sqlite - Adbc","doc":"The SQLite driver provides access to SQLite databases.\n\n#### Examples\n\n    {Adbc.Database, driver: :sqlite, uri: \":memory:\"}\n    {Adbc.Database, driver: :sqlite, uri: \"./db/my.db\"}\n    {Adbc.Database, driver: :sqlite, uri: \"file:/path/to/file/in/disk.db\"}\n\nThe `:uri` option should be, \":memory:\", a filename or\n[URI filename](https://www.sqlite.org/c3ref/open.html#urifilenamesinsqlite3open).\nIf omitted, it will default to an in-memory database, but\none that is shared across all connections.","ref":"Adbc.html#module-sqlite"},{"type":"module","title":"Snowflake - Adbc","doc":"The Snowflake driver provides access to Snowflake Database Warehouses.\n\n#### Examples\n\n    {Adbc.Database, driver: :snowflake, uri: \"...\"}\n\nThe Snowflake URI should be of one of the following formats:\n\n    user[:password]@account/database/schema[?param1=value1&paramN=valueN]\n    user[:password]@account/database[?param1=value1&paramN=valueN]\n    user[:password]@host:port/database/schema?account=user_account[&param1=value1&paramN=valueN]\n    host:port/database/schema?account=user_account[&param1=value1&paramN=valueN]\n\nThe first two are the most recommended formats. The schema, database and parameters are optional.\nSee [Account identifiers](https://docs.snowflake.com/en/user-guide/admin-account-identifier) for more information.","ref":"Adbc.html#module-snowflake"},{"type":"function","title":"Adbc.download_driver/2","doc":"Downloads a driver.\n\nSee `Adbc` module doc for all supports drivers.\nIt returns `:ok` or `{:error, binary}`.","ref":"Adbc.html#download_driver/2"},{"type":"function","title":"Adbc.download_driver!/2","doc":"Downloads a driver and raises in case of errors.\n\nSee `Adbc` module doc for all supports drivers.\nIt returns `:ok`.","ref":"Adbc.html#download_driver!/2"},{"type":"module","title":"Adbc.Column","doc":"Documentation for `Adbc.Column`.\n\n`Adbc.Column` corresponds to a column in the table. It contains the column's name, type, and\ndata. The data is a list of values of the column's data type.","ref":"Adbc.Column.html"},{"type":"function","title":"Adbc.Column.binary/2","doc":"A column that contains binary values.","ref":"Adbc.Column.html#binary/2"},{"type":"function","title":"Arguments - Adbc.Column.binary/2","doc":"* `data`: A list of binary values\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#binary/2-arguments"},{"type":"function","title":"Options - Adbc.Column.binary/2","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#binary/2-options"},{"type":"function","title":"Examples - Adbc.Column.binary/2","doc":"iex> Adbc.Column.binary([<<0>>, <<1>>, <<2>>])\n    %Adbc.Column{\n      name: nil,\n      type: :binary,\n      nullable: false,\n      metadata: nil,\n      data: [<<0>>, <<1>>, <<2>>]\n    }","ref":"Adbc.Column.html#binary/2-examples"},{"type":"function","title":"Adbc.Column.boolean/2","doc":"A column that contains booleans.","ref":"Adbc.Column.html#boolean/2"},{"type":"function","title":"Arguments - Adbc.Column.boolean/2","doc":"* `data`: A list of booleans\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#boolean/2-arguments"},{"type":"function","title":"Options - Adbc.Column.boolean/2","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#boolean/2-options"},{"type":"function","title":"Examples - Adbc.Column.boolean/2","doc":"iex> Adbc.Column.boolean([true, false, true])\n    %Adbc.Column{\n      name: nil,\n      type: :boolean,\n      nullable: false,\n      metadata: nil,\n      data: [true, false, true]\n    }","ref":"Adbc.Column.html#boolean/2-examples"},{"type":"function","title":"Adbc.Column.column/3","doc":"","ref":"Adbc.Column.html#column/3"},{"type":"type","title":"Adbc.Column.data_type/0","doc":"","ref":"Adbc.Column.html#t:data_type/0"},{"type":"function","title":"Adbc.Column.date32/2","doc":"A column that contains date represented as 32-bit signed integers in UTC.","ref":"Adbc.Column.html#date32/2"},{"type":"function","title":"Arguments - Adbc.Column.date32/2","doc":"* `data`: a list, each element of which can be one of the following:\n  * a `Date.t()`\n  * a 32-bit signed integer representing the number of days since the Unix epoch.\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#date32/2-arguments"},{"type":"function","title":"Options - Adbc.Column.date32/2","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#date32/2-options"},{"type":"function","title":"Adbc.Column.date64/2","doc":"A column that contains date represented as 64-bit signed integers in UTC.","ref":"Adbc.Column.html#date64/2"},{"type":"function","title":"Arguments - Adbc.Column.date64/2","doc":"* `data`: a list, each element of which can be one of the following:\n  * a `Date.t()`\n  * a 64-bit signed integer representing the number of milliseconds since the Unix epoch.\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#date64/2-arguments"},{"type":"function","title":"Options - Adbc.Column.date64/2","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#date64/2-options"},{"type":"type","title":"Adbc.Column.decimal128/0","doc":"","ref":"Adbc.Column.html#t:decimal128/0"},{"type":"function","title":"Adbc.Column.decimal128/4","doc":"A column that contains 128-bit decimals.","ref":"Adbc.Column.html#decimal128/4"},{"type":"function","title":"Arguments - Adbc.Column.decimal128/4","doc":"* `data`: a list, each element can be either\n  * a `Decimal.t()`\n  * an `integer()`\n* `precision`: The precision of the decimal values; precision should be between 1 and 38\n* `scale`: The scale of the decimal values\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#decimal128/4-arguments"},{"type":"function","title":"Options - Adbc.Column.decimal128/4","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#decimal128/4-options"},{"type":"type","title":"Adbc.Column.decimal256/0","doc":"","ref":"Adbc.Column.html#t:decimal256/0"},{"type":"function","title":"Adbc.Column.decimal256/4","doc":"A column that contains 256-bit decimals.","ref":"Adbc.Column.html#decimal256/4"},{"type":"function","title":"Arguments - Adbc.Column.decimal256/4","doc":"* `data`: a list, each element can be either\n  * a `Decimal.t()`\n  * an `integer()`\n* `precision`: The precision of the decimal values; precision should be between 1 and 76\n* `scale`: The scale of the decimal values\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#decimal256/4-arguments"},{"type":"function","title":"Options - Adbc.Column.decimal256/4","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#decimal256/4-options"},{"type":"type","title":"Adbc.Column.decimal_t/0","doc":"","ref":"Adbc.Column.html#t:decimal_t/0"},{"type":"function","title":"Adbc.Column.delete_all_metadata/1","doc":"","ref":"Adbc.Column.html#delete_all_metadata/1"},{"type":"function","title":"Adbc.Column.delete_metadata/2","doc":"","ref":"Adbc.Column.html#delete_metadata/2"},{"type":"function","title":"Adbc.Column.dictionary/3","doc":"Construct an array using dictionary encoding.\n\nDictionary encoding is a data representation technique to represent values by integers\nreferencing a dictionary usually consisting of unique values. It can be effective when\nyou have data with many repeated values.\n\nAny array can be dictionary-encoded. The dictionary is stored as an optional property\nof an array. When a field is dictionary encoded, the values are represented by an array\nof non-negative integers representing the index of the value in the dictionary. The memory\nlayout for a dictionary-encoded array is the same as that of a primitive integer layout.\nThe dictionary is handled as a separate columnar array with its own respective layout.\n\nAs an example, you could have the following data:\n\n```elixir\nAdbc.Column.string([\"foo\", \"bar\", \"foo\", \"bar\", nil, \"baz\"], nullable: true)\n```\n\nIn dictionary-encoded form, this could appear as:\n\n```elixir\nAdbc.Column.dictionary(\n  Adbc.Column.string([\"foo\", \"bar\", \"baz\"], nullable: true),\n  Adbc.Column.s32([0, 1, 0, 1, nil, 2], nullable: true)\n)\n```","ref":"Adbc.Column.html#dictionary/3"},{"type":"function","title":"Arguments - Adbc.Column.dictionary/3","doc":"* `data`: a list, each element of which can be one of the following:\n  - `nil`\n  - `Adbc.Column`\n\n  Note that each `Adbc.Column` in the list should have the same type.\n\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#dictionary/3-arguments"},{"type":"function","title":"Options - Adbc.Column.dictionary/3","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#dictionary/3-options"},{"type":"type","title":"Adbc.Column.dictionary_data_t/0","doc":"","ref":"Adbc.Column.html#t:dictionary_data_t/0"},{"type":"function","title":"Adbc.Column.duration/3","doc":"A column that contains durations represented as 64-bit signed integers.","ref":"Adbc.Column.html#duration/3"},{"type":"function","title":"Arguments - Adbc.Column.duration/3","doc":"* `data`: a list of integer values representing the time in the specified unit\n\n* `unit`: specify the unit of the time value, one of the following:\n  * `:seconds`\n  * `:milliseconds`\n  * `:microseconds`\n  * `:nanoseconds`\n\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#duration/3-arguments"},{"type":"function","title":"Options - Adbc.Column.duration/3","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#duration/3-options"},{"type":"type","title":"Adbc.Column.duration_t/0","doc":"","ref":"Adbc.Column.html#t:duration_t/0"},{"type":"function","title":"Adbc.Column.f16/2","doc":"A column that contains 16-bit half-precision floats.","ref":"Adbc.Column.html#f16/2"},{"type":"function","title":"Arguments - Adbc.Column.f16/2","doc":"* `data`: A list of 32-bit single-precision float values (will be converted to 16-bit floats in C)\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#f16/2-arguments"},{"type":"function","title":"Options - Adbc.Column.f16/2","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#f16/2-options"},{"type":"function","title":"Examples - Adbc.Column.f16/2","doc":"iex> Adbc.Column.f16([1.0, 2.0, 3.0])\n    %Adbc.Column{\n      name: nil,\n      type: :f16,\n      nullable: false,\n      metadata: nil,\n      data: [1.0, 2.0, 3.0]\n    }","ref":"Adbc.Column.html#f16/2-examples"},{"type":"function","title":"Adbc.Column.f32/2","doc":"A column that contains 32-bit single-precision floats.","ref":"Adbc.Column.html#f32/2"},{"type":"function","title":"Arguments - Adbc.Column.f32/2","doc":"* `data`: A list of 32-bit single-precision float values\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#f32/2-arguments"},{"type":"function","title":"Options - Adbc.Column.f32/2","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#f32/2-options"},{"type":"function","title":"Examples - Adbc.Column.f32/2","doc":"iex> Adbc.Column.f32([1.0, 2.0, 3.0])\n    %Adbc.Column{\n      name: nil,\n      type: :f32,\n      nullable: false,\n      metadata: nil,\n      data: [1.0, 2.0, 3.0]\n    }","ref":"Adbc.Column.html#f32/2-examples"},{"type":"function","title":"Adbc.Column.f64/2","doc":"A column that contains 64-bit double-precision floats.","ref":"Adbc.Column.html#f64/2"},{"type":"function","title":"Arguments - Adbc.Column.f64/2","doc":"* `data`: A list of 64-bit double-precision float values\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#f64/2-arguments"},{"type":"function","title":"Options - Adbc.Column.f64/2","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#f64/2-options"},{"type":"function","title":"Examples - Adbc.Column.f64/2","doc":"iex> Adbc.Column.f64([1.0, 2.0, 3.0])\n    %Adbc.Column{\n      name: nil,\n      type: :f64,\n      nullable: false,\n      metadata: nil,\n      data: [1.0, 2.0, 3.0]\n    }","ref":"Adbc.Column.html#f64/2-examples"},{"type":"function","title":"Adbc.Column.fixed_size_binary/3","doc":"A column that contains fixed size binaries.\n\nSimilar to `binary/2`, but each binary value has the same fixed size in bytes.","ref":"Adbc.Column.html#fixed_size_binary/3"},{"type":"function","title":"Arguments - Adbc.Column.fixed_size_binary/3","doc":"* `data`: A list of binary values\n* `nbytes`: The fixed size of the binary values in bytes\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#fixed_size_binary/3-arguments"},{"type":"function","title":"Options - Adbc.Column.fixed_size_binary/3","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#fixed_size_binary/3-options"},{"type":"function","title":"Examples - Adbc.Column.fixed_size_binary/3","doc":"iex> Adbc.Column.fixed_size_binary([<<0>>, <<1>>, <<2>>], 1)\n    %Adbc.Column{\n      name: nil,\n      type: {:fixed_size_binary, 1},\n      nullable: false,\n      metadata: nil,\n      data: [<<0>>, <<1>>, <<2>>]\n    }","ref":"Adbc.Column.html#fixed_size_binary/3-examples"},{"type":"function","title":"Adbc.Column.fixed_size_list/3","doc":"Similar to `list/2`, but the length of the list is the same.","ref":"Adbc.Column.html#fixed_size_list/3"},{"type":"function","title":"Arguments - Adbc.Column.fixed_size_list/3","doc":"* `data`: a list, each element of which can be one of the following:\n  - `nil`\n  - `Adbc.Column`\n\n  Note that each `Adbc.Column` in the list should have the same type and length.\n\n* `fixed_size`: The fixed size of the list.\n\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#fixed_size_list/3-arguments"},{"type":"function","title":"Options - Adbc.Column.fixed_size_list/3","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#fixed_size_list/3-options"},{"type":"type","title":"Adbc.Column.floating/0","doc":"","ref":"Adbc.Column.html#t:floating/0"},{"type":"function","title":"Adbc.Column.get_metadata/3","doc":"","ref":"Adbc.Column.html#get_metadata/3"},{"type":"function","title":"Adbc.Column.interval/3","doc":"A column that contains durations represented as signed integers.","ref":"Adbc.Column.html#interval/3"},{"type":"function","title":"Arguments - Adbc.Column.interval/3","doc":"* `data`: a list, each element of which can be one of the following:\n  - if `unit` is `:month`:\n    * a 32-bit signed integer representing the number of months.\n\n  - if `unit` is `:day_time`:\n    * a 2-tuple, both the number of days and the number of milliseconds are in 32-bit signed integers.\n\n  - if `unit` is `:month_day_nano`:\n    * a 3-tuple, the number of months, days, and nanoseconds;\n      the number of months and days are in 32-bit signed integers,\n      and the number of nanoseconds is in 64-bit signed integers\n\n* `unit`: specify the unit of the time value, one of the following:\n  * `:month`\n  * `:day_time`\n  * `:month_day_nano`\n\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#interval/3-arguments"},{"type":"function","title":"Options - Adbc.Column.interval/3","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#interval/3-options"},{"type":"type","title":"Adbc.Column.interval_day_time/0","doc":"","ref":"Adbc.Column.html#t:interval_day_time/0"},{"type":"type","title":"Adbc.Column.interval_month/0","doc":"","ref":"Adbc.Column.html#t:interval_month/0"},{"type":"type","title":"Adbc.Column.interval_month_day_nano/0","doc":"","ref":"Adbc.Column.html#t:interval_month_day_nano/0"},{"type":"type","title":"Adbc.Column.interval_t/0","doc":"","ref":"Adbc.Column.html#t:interval_t/0"},{"type":"type","title":"Adbc.Column.interval_unit/0","doc":"","ref":"Adbc.Column.html#t:interval_unit/0"},{"type":"function","title":"Adbc.Column.large_binary/2","doc":"A column that contains large binary values.\n\nSimilar to `binary/2`, but for binary values larger than 2GB.","ref":"Adbc.Column.html#large_binary/2"},{"type":"function","title":"Arguments - Adbc.Column.large_binary/2","doc":"* `data`: A list of binary values\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#large_binary/2-arguments"},{"type":"function","title":"Options - Adbc.Column.large_binary/2","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#large_binary/2-options"},{"type":"function","title":"Examples - Adbc.Column.large_binary/2","doc":"iex> Adbc.Column.large_binary([<<0>>, <<1>>, <<2>>])\n    %Adbc.Column{\n      name: nil,\n      type: :large_binary,\n      nullable: false,\n      metadata: nil,\n      data: [<<0>>, <<1>>, <<2>>]\n    }","ref":"Adbc.Column.html#large_binary/2-examples"},{"type":"function","title":"Adbc.Column.large_list/2","doc":"Similar to `list/2`, but for large lists.","ref":"Adbc.Column.html#large_list/2"},{"type":"function","title":"Arguments - Adbc.Column.large_list/2","doc":"* `data`: a list, each element of which can be one of the following:\n  - `nil`\n  - `Adbc.Column`\n\n  Note that each `Adbc.Column` in the list should have the same type.\n\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#large_list/2-arguments"},{"type":"function","title":"Options - Adbc.Column.large_list/2","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#large_list/2-options"},{"type":"function","title":"Adbc.Column.large_string/2","doc":"A column that contains UTF-8 encoded large strings.\n\nSimilar to `string/2`, but for strings larger than 2GB.","ref":"Adbc.Column.html#large_string/2"},{"type":"function","title":"Arguments - Adbc.Column.large_string/2","doc":"* `data`: A list of UTF-8 encoded string values\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#large_string/2-arguments"},{"type":"function","title":"Options - Adbc.Column.large_string/2","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#large_string/2-options"},{"type":"function","title":"Examples - Adbc.Column.large_string/2","doc":"iex> Adbc.Column.large_string([\"a\", \"ab\", \"abc\"])\n    %Adbc.Column{\n      name: nil,\n      type: :large_string,\n      nullable: false,\n      metadata: nil,\n      data: [\"a\", \"ab\", \"abc\"]\n    }","ref":"Adbc.Column.html#large_string/2-examples"},{"type":"function","title":"Adbc.Column.list/2","doc":"A column that each row is a list of some type or nil.","ref":"Adbc.Column.html#list/2"},{"type":"function","title":"Arguments - Adbc.Column.list/2","doc":"* `data`: a list, each element of which can be one of the following:\n  - `nil`\n  - `Adbc.Column`\n\n  Note that each `Adbc.Column` in the list should have the same type.\n\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#list/2-arguments"},{"type":"function","title":"Options - Adbc.Column.list/2","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#list/2-options"},{"type":"type","title":"Adbc.Column.list_view_data_t/0","doc":"","ref":"Adbc.Column.html#t:list_view_data_t/0"},{"type":"function","title":"Adbc.Column.materialize/1","doc":"`materialize/1` converts a column's data from reference type to regular Elixir terms.","ref":"Adbc.Column.html#materialize/1"},{"type":"type","title":"Adbc.Column.precision128/0","doc":"","ref":"Adbc.Column.html#t:precision128/0"},{"type":"type","title":"Adbc.Column.precision256/0","doc":"","ref":"Adbc.Column.html#t:precision256/0"},{"type":"type","title":"Adbc.Column.s8/0","doc":"","ref":"Adbc.Column.html#t:s8/0"},{"type":"function","title":"Adbc.Column.s8/2","doc":"A column that contains signed 8-bit integers.","ref":"Adbc.Column.html#s8/2"},{"type":"function","title":"Arguments - Adbc.Column.s8/2","doc":"* `data`: A list of signed 8-bit integer values\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#s8/2-arguments"},{"type":"function","title":"Options - Adbc.Column.s8/2","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#s8/2-options"},{"type":"function","title":"Examples - Adbc.Column.s8/2","doc":"iex> Adbc.Column.s8([1, 2, 3])\n    %Adbc.Column{\n      name: nil,\n      type: :s8,\n      nullable: false,\n      metadata: nil,\n      data: [1, 2, 3]\n    }","ref":"Adbc.Column.html#s8/2-examples"},{"type":"type","title":"Adbc.Column.s16/0","doc":"","ref":"Adbc.Column.html#t:s16/0"},{"type":"function","title":"Adbc.Column.s16/2","doc":"A column that contains signed 16-bit integers.","ref":"Adbc.Column.html#s16/2"},{"type":"function","title":"Arguments - Adbc.Column.s16/2","doc":"* `data`: A list of signed 16-bit integer values\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#s16/2-arguments"},{"type":"function","title":"Options - Adbc.Column.s16/2","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#s16/2-options"},{"type":"function","title":"Examples - Adbc.Column.s16/2","doc":"iex> Adbc.Column.s16([1, 2, 3])\n    %Adbc.Column{\n      name: nil,\n      type: :s16,\n      nullable: false,\n      metadata: nil,\n      data: [1, 2, 3]\n    }","ref":"Adbc.Column.html#s16/2-examples"},{"type":"type","title":"Adbc.Column.s32/0","doc":"","ref":"Adbc.Column.html#t:s32/0"},{"type":"function","title":"Adbc.Column.s32/2","doc":"A column that contains 32-bit signed integers.","ref":"Adbc.Column.html#s32/2"},{"type":"function","title":"Arguments - Adbc.Column.s32/2","doc":"* `data`: A list of 32-bit signed integer values\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#s32/2-arguments"},{"type":"function","title":"Options - Adbc.Column.s32/2","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#s32/2-options"},{"type":"function","title":"Examples - Adbc.Column.s32/2","doc":"iex> Adbc.Column.s32([1, 2, 3])\n    %Adbc.Column{\n      name: nil,\n      type: :s32,\n      nullable: false,\n      metadata: nil,\n      data: [1, 2, 3]\n    }","ref":"Adbc.Column.html#s32/2-examples"},{"type":"type","title":"Adbc.Column.s64/0","doc":"","ref":"Adbc.Column.html#t:s64/0"},{"type":"function","title":"Adbc.Column.s64/2","doc":"A column that contains 64-bit signed integers.","ref":"Adbc.Column.html#s64/2"},{"type":"function","title":"Arguments - Adbc.Column.s64/2","doc":"* `data`: A list of 64-bit signed integer values\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#s64/2-arguments"},{"type":"function","title":"Options - Adbc.Column.s64/2","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#s64/2-options"},{"type":"function","title":"Examples - Adbc.Column.s64/2","doc":"iex> Adbc.Column.s64([1, 2, 3])\n    %Adbc.Column{\n      name: nil,\n      type: :s64,\n      nullable: false,\n      metadata: nil,\n      data: [1, 2, 3]\n    }","ref":"Adbc.Column.html#s64/2-examples"},{"type":"function","title":"Adbc.Column.set_metadata/3","doc":"","ref":"Adbc.Column.html#set_metadata/3"},{"type":"type","title":"Adbc.Column.signed_integer/0","doc":"","ref":"Adbc.Column.html#t:signed_integer/0"},{"type":"function","title":"Adbc.Column.string/2","doc":"A column that contains UTF-8 encoded strings.","ref":"Adbc.Column.html#string/2"},{"type":"function","title":"Arguments - Adbc.Column.string/2","doc":"* `data`: A list of UTF-8 encoded string values\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#string/2-arguments"},{"type":"function","title":"Options - Adbc.Column.string/2","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#string/2-options"},{"type":"function","title":"Examples - Adbc.Column.string/2","doc":"iex> Adbc.Column.string([\"a\", \"ab\", \"abc\"])\n    %Adbc.Column{\n      name: nil,\n      type: :string,\n      nullable: false,\n      metadata: nil,\n      data: [\"a\", \"ab\", \"abc\"]\n    }","ref":"Adbc.Column.html#string/2-examples"},{"type":"type","title":"Adbc.Column.time32_t/0","doc":"","ref":"Adbc.Column.html#t:time32_t/0"},{"type":"type","title":"Adbc.Column.time64_t/0","doc":"","ref":"Adbc.Column.html#t:time64_t/0"},{"type":"function","title":"Adbc.Column.time/3","doc":"A column that contains time represented as signed integers in UTC.","ref":"Adbc.Column.html#time/3"},{"type":"function","title":"Arguments - Adbc.Column.time/3","doc":"* `data`:\n  * a list of `Time.t()` value\n  * a list of integer values representing the time in the specified unit\n\n    Note that when using `:seconds` or `:milliseconds` as the unit,\n    the time value is limited to the range of 32-bit signed integers.\n\n    For `:microseconds` and `:nanoseconds`, the time value is limited to the range of 64-bit signed integers.\n\n* `unit`: specify the unit of the time value, one of the following:\n  * `:seconds`\n  * `:milliseconds`\n  * `:microseconds`\n  * `:nanoseconds`\n\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#time/3-arguments"},{"type":"function","title":"Options - Adbc.Column.time/3","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#time/3-options"},{"type":"type","title":"Adbc.Column.time_t/0","doc":"","ref":"Adbc.Column.html#t:time_t/0"},{"type":"type","title":"Adbc.Column.time_unit/0","doc":"","ref":"Adbc.Column.html#t:time_unit/0"},{"type":"function","title":"Adbc.Column.timestamp/4","doc":"A column that contains timestamps represented as signed integers in the given timezone.","ref":"Adbc.Column.html#timestamp/4"},{"type":"function","title":"Arguments - Adbc.Column.timestamp/4","doc":"* `data`:\n  * a list of `NaiveDateTime.t()` value\n  * a list of 64-bit signed integer values representing the time in the specified unit\n\n* `unit`: specify the unit of the time value, one of the following:\n  * `:seconds`\n  * `:milliseconds`\n  * `:microseconds`\n  * `:nanoseconds`\n\n* `timezone`: the timezone of the timestamp\n\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#timestamp/4-arguments"},{"type":"function","title":"Options - Adbc.Column.timestamp/4","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#timestamp/4-options"},{"type":"type","title":"Adbc.Column.timestamp_t/0","doc":"","ref":"Adbc.Column.html#t:timestamp_t/0"},{"type":"function","title":"Adbc.Column.to_list/1","doc":"Convert a list view, run-end encoding array or a dictionary to a list.","ref":"Adbc.Column.html#to_list/1"},{"type":"function","title":"Examples - Adbc.Column.to_list/1","doc":"iex> list_view = %Adbc.Column{\n    ...>   name: nil,\n    ...>   type: :list_view,\n    ...>   nullable: true,\n    ...>   metadata: nil,\n    ...>   data: %{\n    ...>     values: %Adbc.Column{\n    ...>       name: \"item\",\n    ...>       type: :s32,\n    ...>       nullable: false,\n    ...>       metadata: nil,\n    ...>       data: [0, -127, 127, 50, 12, -7, 25]\n    ...>     },\n    ...>     validity: [true, false, true, true, true],\n    ...>     offsets: [4, 7, 0, 0, 3],\n    ...>     sizes: [3, 0, 4, 0, 2]\n    ...>   }\n    ...> }\n    %Adbc.Column{\n      name: nil,\n      type: :list_view,\n      nullable: true,\n      metadata: nil,\n      data: %{\n        offsets: [4, 7, 0, 0, 3],\n        sizes: [3, 0, 4, 0, 2],\n        validity: [true, false, true, true, true],\n        values: %Adbc.Column{\n          name: \"item\",\n          type: :s32,\n          nullable: false,\n          metadata: nil,\n          data: [0, -127, 127, 50, 12, -7, 25]\n        }\n      }\n    }\n    iex> Adbc.Column.to_list(list_view)\n    %Adbc.Column{\n      name: nil,\n      type: :list,\n      nullable: true,\n      metadata: nil,\n      data: [\n        %Adbc.Column{\n          name: \"item\",\n          type: :s32,\n          nullable: false,\n          metadata: nil,\n          data: [12, -7, 25]\n        },\n        nil,\n        %Adbc.Column{\n          name: \"item\",\n          type: :s32,\n          nullable: false,\n          metadata: nil,\n          data: [0, -127, 127, 50]\n        },\n        %Adbc.Column{\n          name: \"item\",\n          type: :s32,\n          nullable: false,\n          metadata: nil,\n          data: []\n        },\n        %Adbc.Column{\n          name: \"item\",\n          type: :s32,\n          nullable: false,\n          metadata: nil,\n          data: ~c\"2\f\"\n        }\n      ]\n    }","ref":"Adbc.Column.html#to_list/1-examples"},{"type":"type","title":"Adbc.Column.u8/0","doc":"","ref":"Adbc.Column.html#t:u8/0"},{"type":"function","title":"Adbc.Column.u8/2","doc":"A column that contains unsigned 8-bit integers.","ref":"Adbc.Column.html#u8/2"},{"type":"function","title":"Arguments - Adbc.Column.u8/2","doc":"* `data`: A list of unsigned 8-bit integer values\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#u8/2-arguments"},{"type":"function","title":"Options - Adbc.Column.u8/2","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#u8/2-options"},{"type":"function","title":"Examples - Adbc.Column.u8/2","doc":"iex> Adbc.Column.u8([1, 2, 3])\n    %Adbc.Column{\n      name: nil,\n      type: :u8,\n      nullable: false,\n      metadata: nil,\n      data: [1, 2, 3]\n    }","ref":"Adbc.Column.html#u8/2-examples"},{"type":"type","title":"Adbc.Column.u16/0","doc":"","ref":"Adbc.Column.html#t:u16/0"},{"type":"function","title":"Adbc.Column.u16/2","doc":"A column that contains unsigned 16-bit integers.","ref":"Adbc.Column.html#u16/2"},{"type":"function","title":"Arguments - Adbc.Column.u16/2","doc":"* `data`: A list of unsigned 16-bit integer values\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#u16/2-arguments"},{"type":"function","title":"Options - Adbc.Column.u16/2","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#u16/2-options"},{"type":"function","title":"Examples - Adbc.Column.u16/2","doc":"iex> Adbc.Column.u16([1, 2, 3])\n    %Adbc.Column{\n      name: nil,\n      type: :u16,\n      nullable: false,\n      metadata: nil,\n      data: [1, 2, 3]\n    }","ref":"Adbc.Column.html#u16/2-examples"},{"type":"type","title":"Adbc.Column.u32/0","doc":"","ref":"Adbc.Column.html#t:u32/0"},{"type":"function","title":"Adbc.Column.u32/2","doc":"A column that contains un32-bit signed integers.","ref":"Adbc.Column.html#u32/2"},{"type":"function","title":"Arguments - Adbc.Column.u32/2","doc":"* `data`: A list of un32-bit signed integer values\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#u32/2-arguments"},{"type":"function","title":"Options - Adbc.Column.u32/2","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#u32/2-options"},{"type":"function","title":"Examples - Adbc.Column.u32/2","doc":"iex> Adbc.Column.u32([1, 2, 3])\n    %Adbc.Column{\n      name: nil,\n      type: :u32,\n      nullable: false,\n      metadata: nil,\n      data: [1, 2, 3]\n    }","ref":"Adbc.Column.html#u32/2-examples"},{"type":"type","title":"Adbc.Column.u64/0","doc":"","ref":"Adbc.Column.html#t:u64/0"},{"type":"function","title":"Adbc.Column.u64/2","doc":"A column that contains un64-bit signed integers.","ref":"Adbc.Column.html#u64/2"},{"type":"function","title":"Arguments - Adbc.Column.u64/2","doc":"* `data`: A list of un64-bit signed integer values\n* `opts`: A keyword list of options","ref":"Adbc.Column.html#u64/2-arguments"},{"type":"function","title":"Options - Adbc.Column.u64/2","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","ref":"Adbc.Column.html#u64/2-options"},{"type":"function","title":"Examples - Adbc.Column.u64/2","doc":"iex> Adbc.Column.u32([1, 2, 3])\n    %Adbc.Column{\n      name: nil,\n      type: :u32,\n      nullable: false,\n      metadata: nil,\n      data: [1, 2, 3]\n    }","ref":"Adbc.Column.html#u64/2-examples"},{"type":"type","title":"Adbc.Column.unsigned_integer/0","doc":"","ref":"Adbc.Column.html#t:unsigned_integer/0"},{"type":"module","title":"Adbc.Connection","doc":"Documentation for `Adbc.Connection`.\n\nConnection are modelled as processes. They require\nan `Adbc.Database` to be started.","ref":"Adbc.Connection.html"},{"type":"function","title":"Adbc.Connection.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Adbc.Connection.html#child_spec/1"},{"type":"function","title":"Adbc.Connection.get_binary_option/2","doc":"Get a binary (bytes) type option of the connection.","ref":"Adbc.Connection.html#get_binary_option/2"},{"type":"function","title":"Adbc.Connection.get_driver/1","doc":"Gets the underlying driver of a connection process.","ref":"Adbc.Connection.html#get_driver/1"},{"type":"function","title":"Examples - Adbc.Connection.get_driver/1","doc":"ADBC.Connection.get_driver(conn)\n    #=> {:ok, :sqlite}","ref":"Adbc.Connection.html#get_driver/1-examples"},{"type":"function","title":"Adbc.Connection.get_float_option/2","doc":"Get a float type option of the connection.","ref":"Adbc.Connection.html#get_float_option/2"},{"type":"function","title":"Adbc.Connection.get_info/2","doc":"Get metadata about the database/driver.\n\nThe result is an Arrow dataset with the following schema:\n\n\n| Field Name                 |  Field Type    | Null Contstraint  |\n| -------------------------- | ---------------|------------------ |\n| `info_name`                |  `uint32`      | not null          |\n| `info_value`               |  `INFO_SCHEMA` |                   |\n\n`INFO_SCHEMA` is a dense union with members:\n\n| Field Name       | Type Code |  Field Type                   |\n| -----------------| --------- | ----------------------------- |\n| `string_value`              | 0 |  `utf8`                    |\n| `bool_value`                | 1 |  `bool`                    |\n| `int64_value`               | 2 |  `int64`                   |\n| `int32_bitmask`             | 3 |  `int32`                   |\n| `string_list`               | 4 |  `list `              |\n| `int32_to_int32_list_map`   | 5 |  `map >` |\n\nEach metadatum is identified by an integer code. The recognized\ncodes are defined as constants. Codes [0, 10_000) are reserved\nfor ADBC usage. Drivers/vendors will ignore requests for\nunrecognized codes (the row will be omitted from the result).","ref":"Adbc.Connection.html#get_info/2"},{"type":"function","title":"Adbc.Connection.get_integer_option/2","doc":"Get an integer type option of the connection.","ref":"Adbc.Connection.html#get_integer_option/2"},{"type":"function","title":"Adbc.Connection.get_objects/3","doc":"Get a hierarchical view of all catalogs, database schemas, tables, and columns.\n\nThe result is an Arrow dataset with the following schema:\n\n| Field Name               | Field Type                |\n|--------------------------|---------------------------|\n| `catalog_name`           | `utf8`                    |\n| `catalog_db_schemas`     | `list `  |\n\n`DB_SCHEMA_SCHEMA` is a Struct with fields:\n\n| Field Name             | Field Type              |\n|------------------------|-------------------------|\n| `db_schema_name`       | `utf8`                  |\n| `db_schema_tables`     | `list `    |\n\n`TABLE_SCHEMA` is a Struct with fields:\n\n| Field Name           | Field Type                | Null Contstraint   |\n|----------------------|---------------------------|--------------------|\n| `table_name`         | `utf8`                    | not null           |\n| `table_type`         | `utf8`                    | not null           |\n| `table_columns`      | `list `     |                    |\n| `table_constraints`  | `list ` |                    |\n\n`COLUMN_SCHEMA` is a Struct with fields:\n\n| Field Name                 | Field Type  | Null Contstraint | Comments |\n|----------------------------|-------------|------------------|----------|\n| `column_name`              | `utf8`      | not null         |          |\n| `ordinal_position`         | `int32`     |                  | (1)      |\n| `remarks`                  | `utf8`      |                  | (2)      |\n| `xdbc_data_type`           | `int16`     |                  | (3)      |\n| `xdbc_type_name`           | `utf8`      |                  | (3)      |\n| `xdbc_column_size`         | `int32`     |                  | (3)      |\n| `xdbc_decimal_digits`      | `int16`     |                  | (3)      |\n| `xdbc_num_prec_radix`      | `int16`     |                  | (3)      |\n| `xdbc_nullable`            | `int16`     |                  | (3)      |\n| `xdbc_column_def`          | `utf8`      |                  | (3)      |\n| `xdbc_sql_data_type`       | `int16`     |                  | (3)      |\n| `xdbc_datetime_sub`        | `int16`     |                  | (3)      |\n| `xdbc_char_octet_length`   | `int32`     |                  | (3)      |\n| `xdbc_is_nullable`         | `utf8`      |                  | (3)      |\n| `xdbc_scope_catalog`       | `utf8`      |                  | (3)      |\n| `xdbc_scope_schema`        | `utf8`      |                  | (3)      |\n| `xdbc_scope_table`         | `utf8`      |                  | (3)      |\n| `xdbc_is_autoincrement`    | `bool`      |                  | (3)      |\n| `xdbc_is_generatedcolumn`  | `bool`      |                  | (3)      |\n\n1. The column's ordinal position in the table (starting from 1).\n2. Database-specific description of the column.\n3. Optional value. Should be null if not supported by the driver.\n   `xdbc_` values are meant to provide JDBC/ODBC-compatible metadata\n   in an agnostic manner.\n\n`CONSTRAINT_SCHEMA` is a Struct with fields:\n\n| Field Name                | Field Type           | Null Contstraint | Comments |\n|---------------------------|----------------------|------------------|----------|\n| `constraint_name`         | `utf8`               |                  |          |\n| `constraint_type`         | `utf8`               | not null         | (1)      |\n| `constraint_column_names` | `list `         | not null         | (2)      |\n| `constraint_column_usage` | `list ` |                  | (3)      |\n\n1. One of 'CHECK', 'FOREIGN KEY', 'PRIMARY KEY', or 'UNIQUE'.\n2. The columns on the current table that are constrained, in order.\n3. For FOREIGN KEY only, the referenced table and columns.\n\n`USAGE_SCHEMA` is a Struct with fields:\n\n| Field Name               | Field Type    | Null Contstraint |\n|--------------------------|---------------|------------------|\n| `fk_catalog`             | `utf8`        |                  |\n| `fk_db_schema`           | `utf8`        |                  |\n| `fk_table`               | `utf8`        | not null         |\n| `fk_column_name`         | `utf8`        | not null         |","ref":"Adbc.Connection.html#get_objects/3"},{"type":"function","title":"Adbc.Connection.get_string_option/2","doc":"Get a string type option of the connection.","ref":"Adbc.Connection.html#get_string_option/2"},{"type":"function","title":"Adbc.Connection.get_table_types/1","doc":"Get a list of table types in the database.\n\nThe result is an Arrow dataset with the following schema:\n\n| Field Name     | Field Type    | Null Contstraint |\n|----------------|---------------|------------------|\n| `table_type`   | `utf8`        | not null         |","ref":"Adbc.Connection.html#get_table_types/1"},{"type":"function","title":"Adbc.Connection.prepare/2","doc":"Prepares the given `query`.","ref":"Adbc.Connection.html#prepare/2"},{"type":"function","title":"Adbc.Connection.query/4","doc":"Runs the given `query` with `params` and `statement_options`.","ref":"Adbc.Connection.html#query/4"},{"type":"function","title":"Adbc.Connection.query!/4","doc":"Same as `query/4` but raises an exception on error.","ref":"Adbc.Connection.html#query!/4"},{"type":"function","title":"Adbc.Connection.query_pointer/5","doc":"Runs the given `query` with `params` and\npass the ArrowStream pointer to the given function.\n\nThe pointer will point to a valid ArrowStream through\nthe duration of the function. The function may call\nnative code that consumes the ArrowStream accordingly.","ref":"Adbc.Connection.html#query_pointer/5"},{"type":"type","title":"Adbc.Connection.result_set/0","doc":"","ref":"Adbc.Connection.html#t:result_set/0"},{"type":"function","title":"Adbc.Connection.set_option/3","doc":"Set option for the connection.\n\n- If `value` is an atom or a string, then corresponding string option will be set.\n- If `value` is a `{:binary, iodata()}`-tuple, then corresponding binary option will be set.\n- If `value` is an integer, then corresponding integer option will be set.\n- If `value` is a float, then corresponding float option will be set.","ref":"Adbc.Connection.html#set_option/3"},{"type":"function","title":"Adbc.Connection.start_link/1","doc":"Starts a connection process.","ref":"Adbc.Connection.html#start_link/1"},{"type":"function","title":"Options - Adbc.Connection.start_link/1","doc":"* `:database` (required) - the database process to connect to\n\n  * `:process_options` - the options to be given to the underlying\n    process. See `GenServer.start_link/3` for all options","ref":"Adbc.Connection.html#start_link/1-options"},{"type":"function","title":"Examples - Adbc.Connection.start_link/1","doc":"Adbc.Connection.start_link(\n      database: MyApp.DB,\n      process_options: [name: MyApp.Conn]\n    )\n\nIn your supervision tree it would be started like this:\n\n    children = [\n      {Adbc.Connection,\n       database: MyApp.DB,\n       process_options: [name: MyApp.Conn]}\n    ]","ref":"Adbc.Connection.html#start_link/1-examples"},{"type":"type","title":"Adbc.Connection.t/0","doc":"","ref":"Adbc.Connection.html#t:t/0"},{"type":"module","title":"Adbc.Database","doc":"Documentation for `Adbc.Database`.\n\nDatabases are modelled as processes. They required\na driver to be started.","ref":"Adbc.Database.html"},{"type":"function","title":"Adbc.Database.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Adbc.Database.html#child_spec/1"},{"type":"function","title":"Adbc.Database.get_binary_option/2","doc":"Get a binary (bytes) type option of the database.","ref":"Adbc.Database.html#get_binary_option/2"},{"type":"function","title":"Adbc.Database.get_float_option/2","doc":"Get a float type option of the database.","ref":"Adbc.Database.html#get_float_option/2"},{"type":"function","title":"Adbc.Database.get_integer_option/2","doc":"Get an integer type option of the database.","ref":"Adbc.Database.html#get_integer_option/2"},{"type":"function","title":"Adbc.Database.get_string_option/2","doc":"Get a string type option of the database.","ref":"Adbc.Database.html#get_string_option/2"},{"type":"function","title":"Adbc.Database.set_option/3","doc":"Set option for the database.\n\n- If `value` is an atom or a string, then corresponding string option will be set.\n- If `value` is a `{:binary, iodata()}`-tuple, then corresponding binary option will be set.\n- If `value` is an integer, then corresponding integer option will be set.\n- If `value` is a float, then corresponding float option will be set.","ref":"Adbc.Database.html#set_option/3"},{"type":"function","title":"Adbc.Database.start_link/1","doc":"Starts a database process.","ref":"Adbc.Database.html#start_link/1"},{"type":"function","title":"Options - Adbc.Database.start_link/1","doc":"* `:driver` (required) - the driver to use for this database.\n    It must be an atom (see `Adbc` module documentation for all\n    built-in drivers) or a string representing the path to a driver\n\n  * `:process_options` - the options to be given to the underlying\n    process. See `GenServer.start_link/3` for all options\n\nAll other options are given as database options to the underlying driver.","ref":"Adbc.Database.html#start_link/1-options"},{"type":"function","title":"Examples - Adbc.Database.start_link/1","doc":"Adbc.Database.start_link(\n      driver: :sqlite,\n      process_options: [name: MyApp.DB]\n    )\n\nIn your supervision tree it would be started like this:\n\n    children = [\n      {Adbc.Database,\n       driver: :sqlite,\n       process_options: [name: MyApp.DB]},\n    ]","ref":"Adbc.Database.html#start_link/1-examples"},{"type":"module","title":"Adbc.Result","doc":"A struct returned as result from queries.\n\nIt has two fields:\n\n  * `:data` - a list of `Adbc.Column`\n\n  * `:num_rows` - the number of rows returned, if returned\n    by the database","ref":"Adbc.Result.html"},{"type":"function","title":"Adbc.Result.materialize/1","doc":"`materialize/1` converts the result set's data from reference type to regular Elixir terms.","ref":"Adbc.Result.html#materialize/1"},{"type":"type","title":"Adbc.Result.t/0","doc":"","ref":"Adbc.Result.html#t:t/0"},{"type":"function","title":"Adbc.Result.to_list/1","doc":"Convert any list view in the result set to normal lists.","ref":"Adbc.Result.html#to_list/1"},{"type":"function","title":"Adbc.Result.to_map/1","doc":"Returns a map of columns as a result.","ref":"Adbc.Result.html#to_map/1"},{"type":"exception","title":"Adbc.Error","doc":"","ref":"Adbc.Error.html"},{"type":"type","title":"Adbc.Error.t/0","doc":"","ref":"Adbc.Error.html#t:t/0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}